pub async fn get_orders(
    configuration: &Configuration,
    marketplace_ids: Vec<String>,
    created_after: Option<&str>,
    created_before: Option<&str>,
    last_updated_after: Option<&str>,
    last_updated_before: Option<&str>,
    order_statuses: Option<Vec<String>>,
    fulfillment_channels: Option<Vec<String>>,
    payment_methods: Option<Vec<String>>,
    buyer_email: Option<&str>,
    seller_order_id: Option<&str>,
    max_results_per_page: Option<i32>,
    easy_ship_shipment_statuses: Option<Vec<String>>,
    electronic_invoice_statuses: Option<Vec<String>>,
    next_token: Option<&str>,
    amazon_order_ids: Option<Vec<String>>,
    actual_fulfillment_supply_source_id: Option<&str>,
    is_ispu: Option<bool>,
    store_chain_store_id: Option<&str>
) -> Result<GetOrdersResponse, Error>
Returns orders created or updated during the time frame indicated by the specified parameters. You can also apply a range of filtering criteria to narrow the list of orders returned. If NextToken is present, that will be used to retrieve the orders instead of other criteria. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 0.0167 | 20 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values then those shown here. For more information, see Usage Plans and Rate Limits in the Selling Partner API.